#
# spec file for package libspelling
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 1-2
%define api_ver 1

Name:           libspelling
Version:        0.4.7
Release:        1.1
Summary:        A spellcheck library for GTK 4
License:        LGPL-2.1-or-later
URL:            https://gitlab.gnome.org/chergert/libspelling
Source:         %{name}-%{version}.tar.zst

BuildRequires:  c_compiler
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4) >= 4.15.5
BuildRequires:  pkgconfig(gtksourceview-5)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(vapigen)
# For tests
BuildRequires:  myspell-en_US

%description
A spellcheck library for GTK 4.
This library is heavily based upon GNOME Text Editor and GNOME
Builder's spellcheck implementation. However, it is licensed
LGPL-2.1-or-later

%package -n libspelling%{so_ver}
Summary:        Shared libraries for %{name}
Provides:       %{name} = %{version}

%description -n libspelling%{so_ver}
Shared libraries for %{name}.

%package -n typelib-1_0-Spelling-%{api_ver}
Summary:        Introspection file for %{name}

%description -n typelib-1_0-Spelling-1
Introspection file for %{name}.

%package devel
Summary:        Development files for %{name}
Requires:       libspelling%{so_ver} = %{version}
Requires:       typelib-1_0-Spelling-%{api_ver} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D sysprof=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%ldconfig_scriptlets -n libspelling%{so_ver}

%files -n libspelling%{so_ver}
%license COPYING
%doc NEWS README.md
%{_libdir}/libspelling-%{api_ver}.so.*

%files -n typelib-1_0-Spelling-%{api_ver}
%{_libdir}/girepository-1.0/Spelling-%{api_ver}.typelib

%files devel
%doc %{_datadir}/doc/libspelling-%{api_ver}/
%{_includedir}/libspelling-%{api_ver}
%{_libdir}/libspelling-%{api_ver}.so
%{_libdir}/pkgconfig/libspelling-%{api_ver}.pc
%{_datadir}/gir-1.0/Spelling-%{api_ver}.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libspelling-%{api_ver}.deps
%{_datadir}/vala/vapi/libspelling-%{api_ver}.vapi

%files lang -f %{name}.lang

%changelog
* Sun Mar 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.7:
  + Fix a potential assertion failure in B+Tree item removal.
  + Updated translations.
* Mon Jan 27 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.6:
  + Improve detection of asynchronous fragment cancellation to
    break out of long-running spellchecking.
  + Fix Rust example and documentation links.
* Fri Nov 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.5:
  + Various robustness fixes for weak ref tracking
  + Various GObject Introspection fixes
  + A new build option to install a static library
    (libspelling-1.a)
  + Fix a minor leak of extra_word_chars for a language dictionary
  + Fix ICU success check
  + Updated translations.
* Sat Oct 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.4:
  + Adds a few dozen translations for menu items.
- Add lang subpackage and macros. Also provide libspelling from the
  shared lib, allow install of lang subpackage.
* Wed Oct 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.3:
  + Fix build to disable assertions in release builds
  + Fix an off-by-one in assertion
  + Add i18n for translations of menu entries
  + Ignore empty strings when building job list
* Fri Oct  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.2:
  + Limit the number of corrections to 10 in enchant backend to
    help with dictionary configurations which produce many results.
  + Hide add/ignore menu items when disabled.
  + Don't show word corrections when spellcheck is disabled.
- Switch to source service for tarball.
* Fri Sep 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.4.1:
  + Fixes an important issue tracking weak pointers from a
    GtkTextBuffer.
  + Fixes an important issue where we could get invalid text iters
    from GtkTextBuffer::delete-range() after the deletion occurred
    when other signal handlers are in play.
* Tue Sep 10 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.4.0:
  + This is a stable release for GNOME 47.0.
  + Protect the SpellingEngine from systems with misconfigured
    dictionaries.
  + Protect the SpellingTextBufferAdapter from NULL language codes.
  + Protect the SpellingJob from uncooperative break chars which
    could result in zero length runs.
  + Fix some incorrect licenses.
- Changes from version 0.3.1:
  + Immediately clear tags for invalidated regions without
    round-tripping to the checker thread.
  + Bump soname for ABI changes in 0.3
  + Fix licenses to be LGPLv2.1+
  + Add sysprof profiler marks for performance profiling
  + Update example so people know to copy the button-press work to
    update the menu immediately.
  + Fix pkg-config fields
  + Fix libspelling usage from subproject
  + Make introspection building optional
  + Documentation improvements
- Pass sysprof=false to meson configure, do not build the profiler
  support at this time.
- Add so_ver and api_ver define, and set them to 1-2 and 1
  respectivly.
- Add myspell-en_US BuildRequires: Needed for tests.
* Thu Aug  8 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.0:
  + This is an unstable release for GNOME 47.beta.
  + The highlight for this release is a new threaded spellchecking
    engine. It performs text analysis and dictionary lookups in
    bulk off the UI thread. Care is taken to catch collisions in
    the face of user editing while spellchecking operations are in
    flight.
  + I expect a significant reduction in initial spellchecking time
    after opening a document. Opening `gtktextbuffer.c` in Text
    Editor was more than 8x faster.
  + Currently, libspelling relies on GTK main until 4.15.5 is
    released so do keep this in mind if you are a distributor.
  + Some API has changed, though that is unlikely to affect any
    known applications using libspelling.
  + Many new unit tests are part of the testsuite
  + SpellingLanguage was renamed to SpellingDictionary
  + SpellingLanguageInfo was renamed to SpellingLanguage
  + Various helpers were added to SpellingTextBufferAdapter so
    that they can update spelling menus. Applications that update
    the cursor position on clicks before showing menus may want to
    force the menu updating before `menu.popup`.
  + SpellingTextBufferAdapter now uses the new
    GtkTextBufferCommitNotify API in GTK 4.15.5 and newer.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.2.1:
  + Fix licenses to all be LGPLv2.1+.
  + Fix handling of cursor-moved signal.
- Drop 6d26ffd30c78b7f255b1665fac3fb88960ea01ba.patch: fixed
  upstream.
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Oct  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add check section, run meson_test macro during build.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE.
